{% extends "admin/base_site.html" %}
{% load admin_list compressed i18n staticfiles %}

{% block title %}
{% block page_title %}{{form.Meta.title}}{% endblock %} {{block.super}}
{% endblock %}

{% block extrahead %}
<link rel="stylesheet" type="text/css" href="{% static "admin/css/forms.css" %}" />
{%  compressed_css "djblets-admin" %}
{{form.media.render_css|join:''}}
{{block.super}}
{% endblock %}

{% block scripts-post %}
{{block.super}}
{{form.media.render_js|join:''}}
{% endblock %}

{% block bodyclass %}{{block.super}} change-form{% endblock %}

{% block content %}
{%  if form.errors %}
 <p class="errornote">
  {% blocktrans count form.errors.items|length as counter %}Please correct the error below.{% plural %}Please correct the errors below.{% endblocktrans %}
 </p>
{%  endif %}

{% if saved %}
 <ul class="messagelist">
  <li>{% trans "The settings have been saved." %}</li>
 </ul>
{% endif %}

 <h1 class="title">{% block form_title %}{{form.Meta.title}}{% endblock %}</h1>

<div id="content-main">
 <form action="." method="post"{% if form.is_multipart %} enctype="multipart/form-data"{% endif %}>
  {% csrf_token %}
  {{form.non_field_errors}}
{% block form_content %}
{%  include "siteconfig/settings_fieldsets.html" %}
{% endblock %}

{% block submit_row %}
  <div class="submit-row">
{%  block submit_row_buttons %}
   <input type="submit" value="{% trans "Save" %}" class="default" />
{%  endblock submit_row_buttons %}
   <div style="clear: both"></div>
  </div>
{% endblock submit_row %}

 </form>
</div>
{% endblock %}
